@@ -53,8 +53,8 @@ class Cipher(ABC):
             None
 
         Raises:
-            TypeError is raised if this method is called after
-            calling `update`,
+            TypeError is raised if this method is called after calling
+            `update`.
         """
 
     @abstractmethod
@@ -113,6 +113,18 @@ class BaseHash(ABC):
             None
         """
 
+    @abstractmethod
+    def copy(self):
+        """Return a copy of the hash function.
+        This cannot be called after digest has been called.
+
+        Args:
+            None
+
+        Returns:
+            Hash object.
+        """
+
     @abstractmethod
     def digest(self):
         """Finalize and return the hash as bytes object.
@@ -163,15 +175,14 @@ class BaseAsymmetricKey(ABC):
 
 class BasePrivateKey(BaseAsymmetricKey):
     """Represents the base interface for private key."""
+    @abstractmethod
     def signer(self):
         """Instantiate and return a signer object."""
 
-    def exchange(self):
-        """Perform a key exchange."""
-
 
 class BasePublicKey(BaseAsymmetricKey):
     """Represents the base interface for public key."""
+    @abstractmethod
     def verifier(self):
         """Instantiate and return a verifier object."""
 
